@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2022. Christian Heller.
+ * Copyright (C) 1999-2023. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,26 +19,33 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.24.0 2022-12-24
+ * @version CYBOP 0.25.0 2023-03-01
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef BRANCH_SOURCE
 #define BRANCH_SOURCE
 
+#include "../../constant/model/cyboi/log/level_log_cyboi_model.c"
 #include "../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
 #include "../../constant/model/cyboi/state/integer_state_cyboi_model.c"
 #include "../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
+#include "../../constant/model/cyboi/state/state_cyboi_model.c"
+#include "../../constant/name/cyboi/state/item_state_cyboi_name.c"
+#include "../../constant/name/cyboi/state/part_state_cyboi_name.c"
+#include "../../constant/name/cyboi/state/primitive_state_cyboi_name.c"
 #include "../../constant/name/cybol/logic/flow/branch_flow_logic_cybol_name.c"
 #include "../../constant/type/cyboi/state_cyboi_type.c"
 #include "../../executor/accessor/getter/part/name_part_getter.c"
+#include "../../executor/accessor/name_getter/array_name_getter.c"
+#include "../../executor/copier/array_copier.c"
 #include "../../logger/logger.c"
 
 //
 // Forward declarations
 //
 
-void handle(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6, void* p7);
+void handle(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6, void* p7, void* p8);
 
 /**
  * Branches the programme flow, depending on the criterion flag.
@@ -78,12 +85,35 @@ void apply_branch(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, vo
     // Retrieval
     //
 
+    //
+    // CAUTION! There is a DIFFERENCE in how a part containing a cybol path as model is retrieved:
+    //
+    // 1 Leave cybol path as is
+    //
+    // - used in function "copy_array_forward" identifying a tree node by index
+    // - used in function "get_name_array" identifying a tree node by name
+    // - treats cybol path as pure string
+    // - returns the properties of this cybol path part itself
+    //
+    // 2 Resolve cybol path
+    //
+    // - used in functions "get_part_name", "get_part_knowledge", "deserialise_knowledge" identifying a tree node by path
+    // - resolves the cybol path diving deep into the tree hierarchy
+    // - returns the properties of the tree node that the cybol path points to
+    //
+    // Therefore, different functions are used depending on the purpose:
+    //
+    // - copy_array_forward: get part as compound element to be handed over to "handle", done in "handle_element" and "read_signal"
+    // - get_name_array: get part as model to be handed over to "handle", done in sequence/loop/branch
+    // - get_part_name: retrieve the properties belonging to a cybol operation, done in most applicator functions
+    //
+
     // Get criterion part.
     get_part_name((void*) &c, p0, (void*) CRITERION_BRANCH_FLOW_LOGIC_CYBOL_NAME, (void*) CRITERION_BRANCH_FLOW_LOGIC_CYBOL_NAME_COUNT, p1, p2, p3, p4);
     // Get true part.
-    get_part_name((void*) &t, p0, (void*) TRUE_BRANCH_FLOW_LOGIC_CYBOL_NAME, (void*) TRUE_BRANCH_FLOW_LOGIC_CYBOL_NAME_COUNT, p1, p2, p3, p4);
+    get_name_array((void*) &t, p0, (void*) TRUE_BRANCH_FLOW_LOGIC_CYBOL_NAME, (void*) TRUE_BRANCH_FLOW_LOGIC_CYBOL_NAME_COUNT, p1, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL);
     // Get false part.
-    get_part_name((void*) &f, p0, (void*) FALSE_BRANCH_FLOW_LOGIC_CYBOL_NAME, (void*) FALSE_BRANCH_FLOW_LOGIC_CYBOL_NAME_COUNT, p1, p2, p3, p4);
+    get_name_array((void*) &f, p0, (void*) FALSE_BRANCH_FLOW_LOGIC_CYBOL_NAME, (void*) FALSE_BRANCH_FLOW_LOGIC_CYBOL_NAME_COUNT, p1, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL);
 
     // Get criterion part model item.
     copy_array_forward((void*) &cm, c, (void*) POINTER_STATE_CYBOI_TYPE, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) MODEL_PART_STATE_CYBOI_NAME);
@@ -115,12 +145,12 @@ void apply_branch(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, vo
     if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
         // The criterion is true. Handle true model.
-        handle(t, p4, p2, p3, p5, p6, (void*) &x, p7);
+        handle(t, p4, p2, p3, p5, p6, (void*) &x, p7, *NULL_POINTER_STATE_CYBOI_MODEL);
 
     } else {
 
         // The criterion is false. Handle false model.
-        handle(f, p4, p2, p3, p5, p6, (void*) &x, p7);
+        handle(f, p4, p2, p3, p5, p6, (void*) &x, p7, *NULL_POINTER_STATE_CYBOI_MODEL);
     }
 }
 
