@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2022. Christian Heller.
+ * Copyright (C) 1999-2023. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.24.0 2022-12-24
+ * @version CYBOP 0.25.0 2023-03-01
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
@@ -33,18 +33,28 @@
 //
 // CAUTION! These constants have been put into just ONE file,
 // because they have to be assigned a unique identification integer,
-// which is easier to verify having they here altogether.
+// which is easier to verify having them here altogether.
 //
 
 //
-// DOS.
+// base
 //
 
+/** The base-64 cyboi encoding. */
+static int* BASE_64_CYBOI_ENCODING = NUMBER_0_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+//
+// dos
+//
+
+/** The dos 437 cyboi encoding. */
+static int* DOS_437_CYBOI_ENCODING = NUMBER_100_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
 /** The dos 850 cyboi encoding. */
-static int* DOS_850_CYBOI_ENCODING = NUMBER_100_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* DOS_850_CYBOI_ENCODING = NUMBER_101_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 //
-// General.
+// general
 //
 
 /** The ascii cyboi encoding. */
@@ -66,7 +76,7 @@ static int* SHIFT_JIS_CYBOI_ENCODING = NUMBER_204_INTEGER_STATE_CYBOI_MODEL_ARRA
 static int* UNIVERSAL_CYBOI_ENCODING = NUMBER_205_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 //
-// ISO 8859.
+// iso 8859
 //
 
 /** The iso-8859-1 cyboi encoding. */
@@ -118,7 +128,7 @@ static int* ISO_8859_15_CYBOI_ENCODING = NUMBER_315_INTEGER_STATE_CYBOI_MODEL_AR
 static int* ISO_8859_16_CYBOI_ENCODING = NUMBER_316_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 //
-// Unicode.
+// unicode
 //
 
 /** The cesu-8 cyboi encoding. */
@@ -149,7 +159,7 @@ static int* UTF_EBCDIC_CYBOI_ENCODING = NUMBER_507_INTEGER_STATE_CYBOI_MODEL_ARR
 static int* UTF_SCSU_CYBOI_ENCODING = NUMBER_508_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 //
-// Windows.
+// windows
 //
 
 /** The windows 874 cyboi encoding. */
