@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2022. Christian Heller.
+ * Copyright (C) 1999-2023. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.24.0 2022-12-24
+ * @version CYBOP 0.25.0 2023-03-01
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
@@ -39,11 +39,11 @@
 // This file contains character encoding constants.
 //
 
-/*
- * The dos-850 cybol encoding.
- *
- * Disk Operating System (DOS) Code page 850.
- */
+/* The dos-437 cybol encoding. */
+static wchar_t* DOS_437_CYBOL_ENCODING = L"dos-437";
+static int* DOS_437_CYBOL_ENCODING_COUNT = NUMBER_7_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/* The dos-850 cybol encoding. */
 static wchar_t* DOS_850_CYBOL_ENCODING = L"dos-850";
 static int* DOS_850_CYBOL_ENCODING_COUNT = NUMBER_7_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
