@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2022. Christian Heller.
+ * Copyright (C) 1999-2023. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.24.0 2022-12-24
+ * @version CYBOP 0.25.0 2023-03-01
  * @author Christian Heller <christian.heller@cybop.org>
  * @author Franziska Wehner <franziska.wehner@it2011.ba-leipzig.de>
  */
@@ -393,6 +393,9 @@ static int* PART_ELEMENT_STATE_CYBOI_FORMAT = NUMBER_300_INTEGER_STATE_CYBOI_MOD
 /** The property element state cyboi format. */
 static int* PROPERTY_ELEMENT_STATE_CYBOI_FORMAT = NUMBER_301_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
+/** The reference element state cyboi format. */
+static int* REFERENCE_ELEMENT_STATE_CYBOI_FORMAT = NUMBER_302_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
 //
 // example
 //
