@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2022. Christian Heller.
+ * Copyright (C) 1999-2023. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.24.0 2022-12-24
+ * @version CYBOP 0.25.0 2023-03-01
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
@@ -44,25 +44,28 @@
 void decode_iso_8859_character(void* p0, void* p1, void* p2) {
 
     log_message_terminated((void*) DEBUG_LEVEL_LOG_CYBOI_MODEL, (void*) L"Decode iso-8859 character.");
+    //?? fwprintf(stdout, L"Debug: Decode iso-8859 character. p1: %i\n", p1);
 
     // The comparison result.
     int r = *FALSE_BOOLEAN_STATE_CYBOI_MODEL;
+    // The range border.
+    unsigned char b = (unsigned char) *NUMBER_0_INTEGER_STATE_CYBOI_MODEL;
 
     //
     // Characters 0..127 (ascii)
     //
 
-    //?? fwprintf(stdout, L"Debug: decode iso-8859 character: %i\n", r);
-
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
+        // Cast range border.
+        b = (unsigned char) *NUMBER_128_INTEGER_STATE_CYBOI_MODEL;
+
         // CAUTION! Do NOT use function "compare_integer_less" here.
-        // It will not work correctly.
-        compare_character_less((void*) &r, p1, (void*) NUMBER_128_INTEGER_STATE_CYBOI_MODEL);
+        compare_character_less((void*) &r, p1, (void*) &b);
 
         if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-            //?? fwprintf(stdout, L"Debug: decode iso-8859 character ascii: %i\n", r);
+            //?? fwprintf(stdout, L"Debug: Decode iso-8859 character. ascii: %i\n", r);
 
             decode_ascii(p0, p1);
         }
@@ -74,7 +77,7 @@ void decode_iso_8859_character(void* p0, void* p1, void* p2) {
 
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-        //?? fwprintf(stdout, L"Debug: decode iso-8859 character iso: %i\n", r);
+        //?? fwprintf(stdout, L"Debug: Decode iso-8859 character. iso: %i\n", r);
 
         decode_iso_8859_extension(p0, p1, p2);
     }
