@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2022. Christian Heller.
+ * Copyright (C) 1999-2023. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.24.0 2022-12-24
+ * @version CYBOP 0.25.0 2023-03-01
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
@@ -54,9 +54,12 @@ void copy_array_elements_forward(void* p0, void* p1, void* p2, void* p3, void* p
     //
     // CAUTION! Do NOT call the logger here.
     // It uses functions causing circular references.
+    //
     // log_message_terminated((void*) DEBUG_LEVEL_LOG_CYBOI_MODEL, (void*) L"Copy array elements forward.");
     //
 
+    //?? fwprintf(stdout, L"Debug: Copy array elements forward. p3: %i\n", p3);
+
     // The loop variable.
     int j = *NUMBER_0_INTEGER_STATE_CYBOI_MODEL;
     // The break flag.
@@ -64,11 +67,14 @@ void copy_array_elements_forward(void* p0, void* p1, void* p2, void* p3, void* p
 
     if (p4 == *NULL_POINTER_STATE_CYBOI_MODEL) {
 
+        //?? fwprintf(stdout, L"Debug: Copy array elements forward. p4: %i\n", p4);
+
         //
         // CAUTION! If the loop count handed over as parametre is NULL,
         // then the break flag will NEVER be set to true, because the loop
         // variable comparison does (correctly) not consider null values.
         // Therefore, in this case, the break flag is set to true already here.
+        //
         // Initialising the break flag with true will NOT work either, since it:
         // a) will be left untouched if a comparison operand is null;
         // b) would have to be reset to true in each loop cycle.
@@ -105,6 +111,7 @@ void copy_array_elements_forward(void* p0, void* p1, void* p2, void* p3, void* p
 void copy_array_elements_backward(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
     log_message_terminated((void*) DEBUG_LEVEL_LOG_CYBOI_MODEL, (void*) L"Copy array elements backward.");
+    //?? fwprintf(stdout, L"Debug: Copy array elements backward. p3: %i\n", p3);
 
     // The loop variable.
     int j = *NUMBER_0_INTEGER_STATE_CYBOI_MODEL;
@@ -118,6 +125,7 @@ void copy_array_elements_backward(void* p0, void* p1, void* p2, void* p3, void*
         // then the break flag will NEVER be set to true, because the loop
         // variable comparison does (correctly) not consider null values.
         // Therefore, in this case, the break flag is set to true already here.
+        //
         // Initialising the break flag with true will NOT work either, since it:
         // a) will be left untouched if a comparison operand is null;
         // b) would have to be reset to true in each loop cycle.
@@ -175,11 +183,13 @@ void copy_array_forward(void* p0, void* p1, void* p2, void* p3, void* p4, void*
             //
             // CAUTION! Do NOT call the logger here.
             // It uses functions causing circular references.
+            //
             // log_message_terminated((void*) DEBUG_LEVEL_LOG_CYBOI_MODEL, (void*) L"Copy array forward.");
             //
 
             //
             // The destination array, source array.
+            //
             // CAUTION! They HAVE TO BE initialised with p0 and p1,
             // since an offset is added below.
             //
@@ -196,8 +206,11 @@ void copy_array_forward(void* p0, void* p1, void* p2, void* p3, void* p4, void*
             //
             // CAUTION! Do NOT call the logger here.
             // It uses functions causing circular references.
+            //
             // log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not copy array forward. The destination array is null.");
             //
+
+            fwprintf(stdout, L"Error: Could not copy array forward. The destination array is null. p0: %i\n", p0);
         }
 
     } else {
@@ -205,8 +218,11 @@ void copy_array_forward(void* p0, void* p1, void* p2, void* p3, void* p4, void*
         //
         // CAUTION! Do NOT call the logger here.
         // It uses functions causing circular references.
+        //
         // log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not copy array forward. The source array is null.");
         //
+
+        //?? fwprintf(stdout, L"Error: Could not copy array forward. The source array is null. p1: %i\n", p1);
     }
 }
 
@@ -237,7 +253,7 @@ void copy_array_backward(void* p0, void* p1, void* p2, void* p3, void* p4, void*
 
         if (p0 != *NULL_POINTER_STATE_CYBOI_MODEL) {
 
-            log_message_terminated((void*) DEBUG_LEVEL_LOG_CYBOI_MODEL, (void*) L"Copy array backward.");
+            //?? log_message_terminated((void*) DEBUG_LEVEL_LOG_CYBOI_MODEL, (void*) L"Copy array backward.");
 
             //
             // The destination array, source array.
@@ -256,11 +272,13 @@ void copy_array_backward(void* p0, void* p1, void* p2, void* p3, void* p4, void*
         } else {
 
             log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not copy array backward. The destination array is null.");
+            fwprintf(stdout, L"Error: Could not copy array forward. The destination array is null. p0: %i\n", p0);
         }
 
     } else {
 
         log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not copy array backward. The source array is null.");
+        fwprintf(stdout, L"Error: Could not copy array forward. The source array is null. p1: %i\n", p1);
     }
 }
 
