@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2022. Christian Heller.
+ * Copyright (C) 1999-2023. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.24.0 2022-12-24
+ * @version CYBOP 0.25.0 2023-03-01
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
@@ -59,6 +59,9 @@ void copy(void* p0, void* p1, void* p2, void* p3) {
     // It uses functions causing circular references.
     //
     // log_message_terminated((void*) DEBUG_LEVEL_LOG_CYBOI_MODEL, (void*) L"Copy.");
+    //
+
+    //?? fwprintf(stdout, L"Debug: Copy. p3: %i\n", p3);
 
     // The comparison result.
     int r = *FALSE_BOOLEAN_STATE_CYBOI_MODEL;
@@ -133,17 +136,23 @@ void copy(void* p0, void* p1, void* p2, void* p3) {
                 // Therefore, do NOT offer shallow copying as a property (option)
                 // to cybol container operations like "overwrite" or "insert"!
                 // Take deep copying AS DEFAULT inside.
-                // Otherwise, the knowledge tree might get mixed up,
-                // e.g. with circular references. But it should always be a
+                // Otherwise, the knowledge tree might get mixed up, for example
+                // with circular references. But it should always be a
                 // Directed Acyclic Graph (DAG) with unidirectional references.
                 //
 
+                //?? fwprintf(stdout, L"Debug: copy shallow pre: %i\n", r);
+
+                //
+                // Copy pointer.
                 //
                 // CAUTION! Both, the destination- as well as the source value
                 // will get interpreted as pointer reference inside.
                 //
                 copy_pointer(p0, p1);
 
+                //?? fwprintf(stdout, L"Debug: copy shallow post: %i\n", r);
+
             } else {
 
                 //
@@ -157,11 +166,11 @@ void copy(void* p0, void* p1, void* p2, void* p3) {
                 //
                 // For copying whole sub trees to another place.
                 //
-                // It is also used when storing variables on stack memory.
-                //
 
                 //?? fwprintf(stdout, L"Debug: copy deep pre: %i\n", r);
 
+                //
+                // Copy part.
                 //
                 // CAUTION! Both, the destination- as well as the source value
                 // will get interpreted as pointer reference inside.
@@ -284,8 +293,11 @@ void copy(void* p0, void* p1, void* p2, void* p3) {
         //
         // CAUTION! Do NOT call the logger here.
         // It uses functions causing circular references.
+        //
         // log_message_terminated((void*) WARNING_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not copy. The operand type is unknown.");
         //
+        fwprintf(stdout, L"Warning: Could not copy. The operand type is unknown. p2: %i\n", p2);
+        fwprintf(stdout, L"Warning: Could not copy. The operand type is unknown. *p2: %i\n", *((int*) p2));
     }
 }
 
@@ -306,6 +318,9 @@ void copy_offset(void* p0, void* p1, void* p2, void* p3, void* p4) {
     // It uses functions causing circular references.
     //
     // log_message_terminated((void*) DEBUG_LEVEL_LOG_CYBOI_MODEL, (void*) L"Copy offset.");
+    //
+
+    //?? fwprintf(stdout, L"Debug: Copy offset. p3: %i\n", p3);
 
     //
     // The destination value, source value.
