@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2022. Christian Heller.
+ * Copyright (C) 1999-2023. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.24.0 2022-12-24
+ * @version CYBOP 0.25.0 2023-03-01
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
@@ -57,6 +57,7 @@
 void modify_item(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6, void* p7, void* p8, void* p9, void* p10, void* p11) {
 
     log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Modify item.");
+    //?? fwprintf(stdout, L"Debug: Modify item. p3: %i\n", p3);
 
     // The destination data, count, size.
     void* d = *NULL_POINTER_STATE_CYBOI_MODEL;
@@ -70,6 +71,19 @@ void modify_item(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, voi
     copy_array_forward((void*) &c, p0, (void*) POINTER_STATE_CYBOI_TYPE, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) COUNT_ITEM_STATE_CYBOI_NAME);
     copy_array_forward((void*) &s, p0, (void*) POINTER_STATE_CYBOI_TYPE, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) SIZE_ITEM_STATE_CYBOI_NAME);
 
+    if (DEBUG_CYBOP == 1) {
+        fwprintf(stdout, L"Debug: Modify item. count p4: %i\n", p4);
+        fwprintf(stdout, L"Debug: Modify item. count *p4: %i\n", *((int*) p4));
+        fwprintf(stdout, L"Debug: Modify item. destination index p5: %i\n", p5);
+        fwprintf(stdout, L"Debug: Modify item. destination index *p5: %i\n", *((int*) p5));
+        fwprintf(stdout, L"Debug: Modify item. source index p6: %i\n", p6);
+        fwprintf(stdout, L"Debug: Modify item. source index *p6: %i\n", *((int*) p6));
+        fwprintf(stdout, L"Debug: Modify item. destination count c: %i\n", c);
+        fwprintf(stdout, L"Debug: Modify item. destination count *c: %i\n", *((int*) c));
+        fwprintf(stdout, L"Debug: Modify item. operation type p11: %i\n", p11);
+        fwprintf(stdout, L"Debug: Modify item. operation type *p11: %i\n", *((int*) p11));
+    }
+
     //
     // CAUTION! Some functions called internally do NOT use a source index.
     // For these cases, the destination count determined above is handed over.
@@ -77,6 +91,9 @@ void modify_item(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, voi
     //
     modify_verify((void*) &r, p4, p5, p6, c, p4, p11);
 
+    //?? TODO TEST: DELETE later!
+    r = *TRUE_BOOLEAN_STATE_CYBOI_MODEL;
+
     if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
         //
@@ -104,7 +121,7 @@ void modify_item(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, voi
         // might contain data in some cases, but in other cases be empty on purpose.
         //
         //?? log_message_terminated((void*) WARNING_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not modify item. The sum of the given index and count is outside the data array count. This may be regular behaviour. Probably, the model pointed to by a cybol path is null or empty or a cybol model (e.g. a string) is wrong since it was not emptied before being filled.");
-        //?? fwprintf(stdout, L"Warning: Could not modify item. The sum of the given index and count is outside the data array count. This may be regular behaviour. Probably, the model pointed to by a cybol path is null or empty or a cybol model (e.g. a string) is wrong since it was not emptied before being filled. r: %i\n", r);
+        fwprintf(stdout, L"Warning: Could not modify item. The sum of the given index and count is outside the data array count. This may be regular behaviour. Probably, the model pointed to by a cybol path is null or empty or a cybol model (e.g. a string) is wrong since it was not emptied before being filled. r: %i\n", r);
     }
 }
 
