@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2022. Christian Heller.
+ * Copyright (C) 1999-2023. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.24.0 2022-12-24
+ * @version CYBOP 0.25.0 2023-03-01
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
@@ -29,6 +29,7 @@
 #include "../../../../constant/format/cyboi/logic_cyboi_format.c"
 #include "../../../../constant/encoding/cyboi/cyboi_encoding.c"
 #include "../../../../constant/encoding/cybol/cybol_encoding.c"
+#include "../../../../constant/encoding/cybol/base_cybol_encoding.c"
 #include "../../../../constant/encoding/cybol/dos_cybol_encoding.c"
 #include "../../../../constant/encoding/cybol/iso_8859_cybol_encoding.c"
 #include "../../../../constant/encoding/cybol/unicode_cybol_encoding.c"
@@ -67,9 +68,33 @@ void deserialise_cybol_encoding(void* p0, void* p1, void* p2) {
     int r = *FALSE_BOOLEAN_STATE_CYBOI_MODEL;
 
     //
-    // DOS
+    // base
     //
 
+    if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
+
+        check_operation((void*) &r, p1, (void*) BASE_64_CYBOL_ENCODING, p2, (void*) BASE_64_CYBOL_ENCODING_COUNT, (void*) EQUAL_COMPARE_LOGIC_CYBOI_FORMAT, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
+
+        if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
+
+            modify_item(p0, (void*) BASE_64_CYBOI_ENCODING, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) TRUE_BOOLEAN_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, (void*) OVERWRITE_MODIFY_LOGIC_CYBOI_FORMAT);
+        }
+    }
+
+    //
+    // dos
+    //
+
+    if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
+
+        check_operation((void*) &r, p1, (void*) DOS_437_CYBOL_ENCODING, p2, (void*) DOS_437_CYBOL_ENCODING_COUNT, (void*) EQUAL_COMPARE_LOGIC_CYBOI_FORMAT, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
+
+        if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
+
+            modify_item(p0, (void*) DOS_437_CYBOI_ENCODING, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) TRUE_BOOLEAN_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, (void*) OVERWRITE_MODIFY_LOGIC_CYBOI_FORMAT);
+        }
+    }
+
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
         check_operation((void*) &r, p1, (void*) DOS_850_CYBOL_ENCODING, p2, (void*) DOS_850_CYBOL_ENCODING_COUNT, (void*) EQUAL_COMPARE_LOGIC_CYBOI_FORMAT, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
@@ -81,7 +106,7 @@ void deserialise_cybol_encoding(void* p0, void* p1, void* p2) {
     }
 
     //
-    // General
+    // general
     //
 
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
@@ -95,7 +120,7 @@ void deserialise_cybol_encoding(void* p0, void* p1, void* p2) {
     }
 
     //
-    // ISO-8859
+    // iso 8859
     //
 
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
@@ -259,7 +284,7 @@ void deserialise_cybol_encoding(void* p0, void* p1, void* p2) {
     }
 
     //
-    // Unicode
+    // unicode
     //
 
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
@@ -283,7 +308,7 @@ void deserialise_cybol_encoding(void* p0, void* p1, void* p2) {
     }
 
     //
-    // Windows
+    // windows
     //
 
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
